Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5627)

Unified Diff: chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h

Issue 1770573002: Update extension buttons to Material Design (Mac). (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@md_toolbar
Patch Set: Code clean-up. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h
diff --git a/chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h b/chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h
index 73b36b7a74cbba4224a9d948724ba75a4dd6f4fc..d4d904ebcb125b060a548289bb0cff861d1dca6a 100644
--- a/chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h
+++ b/chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.h
@@ -25,15 +25,20 @@ enum class ToolbarButtonImageBackgroundStyle {
BOOL handleMiddleClick_;
}
+// Return the size of toolbar buttons.
++ (NSSize)toolbarButtonSize;
// Whether or not to handle the mouse middle click events.
@property(assign, nonatomic) BOOL handleMiddleClick;
-// Override point for subclasses to return their icon color.
-- (SkColor)iconColor:(BOOL)themeIsDark;
-// Sets images for each of the ToolbarButton's states from the specified
-// vector icon.
-- (void)setImagesFromIconId:(gfx::VectorIconId)iconId;
-// Override point for subclasses to set the button's icons.
-- (void)resetIcons;
+// Override point for subclasses to return their vector icon id.
+- (gfx::VectorIconId)vectorIconId;
+// Override point for subclasses to return their vector icon color.
+- (SkColor)vectorIconColor:(BOOL)themeIsDark;
+// When in Material Design mode, sets the images for each of the ToolbarButton's
+// states from the specified image.
+- (void)setImage:(NSImage*)anImage;
+// Resets the images for each of the ToolbarButton's states from its vector icon
+// id or its main image. Should only be called when in Material Design mode.
+- (void)resetButtonStateImages;
@end
@interface ToolbarButton (ExposedForTesting)
« no previous file with comments | « chrome/browser/ui/cocoa/toolbar/reload_button_cocoa.mm ('k') | chrome/browser/ui/cocoa/toolbar/toolbar_button_cocoa.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698